==> ChurchCRM-4.4.5.zip: churchcrm/locale/js/th_TH.js <==
// Source: locale/JSONKeys/th_TH.json
try {window.CRM.i18keys = {
    "Cannot execute query.": "ไม่สามารถสืบค้นฐานข้อมูล",
    "Delete": "ลบ",
    "Cancel": "ยกเลิก",
    "Save": "บันทึก",
    "Unassigned": "ยังไม่ได้กำหนด",
    "None": "ไม่มี",
    "City": "เมือง",
    "State": "จังหวัด",
    "Country": "ประเทศ",
    "Phone": "โทรศัพท์",
    "Email": "อีเมล",
    "Credit Card": "บัตรเครดิต",
    "Backup Database": "ฐานข้อมูลสำรอง",
    "Select archive type": "เลือกประเภทเก็บ",
    "Re-type Password": "พิมพ์รหัสผ่านอีกครั้ง",
    "Winner": "ผู้ชนะ",
    "Price": "ราคา",
    "Enter Winners": "ลงชื่อผู้ชนะ",
    "CSV Export": "ส่งไฟล์ CSV ออก",
    "Field Selection": "เลือกฟิลด์",
    "Last Name": "นามสกุล",
    "Required": "ฟิลด์ที่จำเป็น",
    "First Name": "ชื่อจริง",
    "Middle Name": "ชื่อกลาง",
    "Zip": "รหัสไปรษณีย์",
    "Envelope": "ซอง",
    "Work/Other Email": "อีเมล ที่ทำงาน/ที่อื่นๆ",
    "Membership Date": "วันที่เป็นสมาชิก",
    "Birth / Anniversary Date": "วันเกิด / วันครอบรอบแต่งงาน",
    "Age / Years Married": "อายุ / แต่งงานกี่ปีแล้ว",
    "Family Role": "บทบาทในครอบครัว",
    "Filters": "ฟิลเตอร์",
    "Based on filters below..": "ขึ้นอยู่กับฟิลเตอร์ด้านล่าง",
    "People in Cart (filters ignored)": "คนในรถเข็น",
    "Use Ctrl Key to select multiple": "ใช้ Ctrl คีย์เพื่อเลือกหลาย",
    "Don't Filter": "ไม่ใช้ฟิลเตอร์",
    "Male": "ชาย",
    "Female": "หญิง",
    "Group Membership": "สมาชิกกลุ่ม",
    "From:": "จาก",
    "To:": "เรียน",
    "Birthday Date": "วันเกิด",
    "Anniversary Date": "วันครบรอบแต่งงาน",
    "Output Method:": "วิธีการส่งออก",
    "Create File": "สร้างไฟล์",
    "Gender": "เพศ",
    "Donation Envelope": "ซองถวาย",
    "Home Phone": "โทรศัพท์บ้าน",
    "Work Phone": "โทรศัพท์ที่ทำงาน",
    "Mobile Phone": "โทรศัพท์มือถือ",
    "Work / Other Email": "อีเมล ที่ทำงาน / ที่อื่นๆ",
    "Birth Date": "วันเกิด",
    "Wedding Date": "วันแต่งงาน",
    "Make Family records based on last name and address": "ข้อมูลแต่ละครอบครัวโดยเรียงตามลำดับอักษรของนามสกุลและที่อยู่",
    "Patriarch": "ผู้ชายที่อยู่ในวงศาคณาญาติที่เราให้ความเคารพ",
    "Matriarch": "ผู้หญิงที่อยู่ในวงศาคณาญาติที่เราให้ความเคารพ",
    "Login": "เข้าสู่ระบบ",
    "Login Name": "ชื่อผู้ใช้",
    "Last Login": "เข้าสู่ระบบครั้งล่าสุด"
};} catch(e) {};

// Source: node_modules/fullcalendar/dist/locale/th.js
try {!function(e,t){"object"==typeof exports&&"object"==typeof module?module.exports=t(require("moment"),require("fullcalendar")):"function"==typeof define&&define.amd?define(["moment","fullcalendar"],t):"object"==typeof exports?t(require("moment"),require("fullcalendar")):t(e.moment,e.FullCalendar)}("undefined"!=typeof self?self:this,function(e,t){return function(e){function t(r){if(n[r])return n[r].exports;var o=n[r]={i:r,l:!1,exports:{}};return e[r].call(o.exports,o,o.exports,t),o.l=!0,o.exports}var n={};return t.m=e,t.c=n,t.d=function(e,n,r){t.o(e,n)||Object.defineProperty(e,n,{configurable:!1,enumerable:!0,get:r})},t.n=function(e){var n=e&&e.__esModule?function(){return e.default}:function(){return e};return t.d(n,"a",n),n},t.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},t.p="",t(t.s=203)}({0:function(t,n){t.exports=e},1:function(e,n){e.exports=t},203:function(e,t,n){Object.defineProperty(t,"__esModule",{value:!0}),n(204);var r=n(1);r.datepickerLocale("th","th",{closeText:"ปิด",prevText:"&#xAB;&#xA0;ย้อน",nextText:"ถัดไป&#xA0;&#xBB;",currentText:"วันนี้",monthNames:["มกราคม","กุมภาพันธ์","มีนาคม","เมษายน","พฤษภาคม","มิถุนายน","กรกฎาคม","สิงหาคม","กันยายน","ตุลาคม","พฤศจิกายน","ธันวาคม"],monthNamesShort:["ม.ค.","ก.พ.","มี.ค.","เม.ย.","พ.ค.","มิ.ย.","ก.ค.","ส.ค.","ก.ย.","ต.ค.","พ.ย.","ธ.ค."],dayNames:["อาทิตย์","จันทร์","อังคาร","พุธ","พฤหัสบดี","ศุกร์","เสาร์"],dayNamesShort:["อา.","จ.","อ.","พ.","พฤ.","ศ.","ส."],dayNamesMin:["อา.","จ.","อ.","พ.","พฤ.","ศ.","ส."],weekHeader:"Wk",dateFormat:"dd/mm/yy",firstDay:0,isRTL:!1,showMonthAfterYear:!1,yearSuffix:""}),r.locale("th",{buttonText:{month:"เดือน",week:"สัปดาห์",day:"วัน",list:"แผนงาน"},allDayText:"ตลอดวัน",eventLimitText:"เพิ่มเติม",noEventsMessage:"ไม่มีกิจกรรมที่จะแสดง"})},204:function(e,t,n){!function(e,t){t(n(0))}(0,function(e){return e.defineLocale("th",{months:"มกราคม_กุมภาพันธ์_มีนาคม_เมษายน_พฤษภาคม_มิถุนายน_กรกฎาคม_สิงหาคม_กันยายน_ตุลาคม_พฤศจิกายน_ธันวาคม".split("_"),monthsShort:"ม.ค._ก.พ._มี.ค._เม.ย._พ.ค._มิ.ย._ก.ค._ส.ค._ก.ย._ต.ค._พ.ย._ธ.ค.".split("_"),monthsParseExact:!0,weekdays:"อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัสบดี_ศุกร์_เสาร์".split("_"),weekdaysShort:"อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัส_ศุกร์_เสาร์".split("_"),weekdaysMin:"อา._จ._อ._พ._พฤ._ศ._ส.".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY เวลา H:mm",LLLL:"วันddddที่ D MMMM YYYY เวลา H:mm"},meridiemParse:/ก่อนเที่ยง|หลังเที่ยง/,isPM:function(e){return"หลังเที่ยง"===e},meridiem:function(e,t,n){return e<12?"ก่อนเที่ยง":"หลังเที่ยง"},calendar:{sameDay:"[วันนี้ เวลา] LT",nextDay:"[พรุ่งนี้ เวลา] LT",nextWeek:"dddd[หน้า เวลา] LT",lastDay:"[เมื่อวานนี้ เวลา] LT",lastWeek:"[วัน]dddd[ที่แล้ว เวลา] LT",sameElse:"L"},relativeTime:{future:"อีก %s",past:"%sที่แล้ว",s:"ไม่กี่วินาที",ss:"%d วินาที",m:"1 นาที",mm:"%d นาที",h:"1 ชั่วโมง",hh:"%d ชั่วโมง",d:"1 วัน",dd:"%d วัน",M:"1 เดือน",MM:"%d เดือน",y:"1 ปี",yy:"%d ปี"}})})}})});} catch(e) {};

// Source: node_modules/bootstrap-datepicker/dist/locales/bootstrap-datepicker.th.min.js
try {!function(a){a.fn.datepicker.dates.th={days:["อาทิตย์","จันทร์","อังคาร","พุธ","พฤหัส","ศุกร์","เสาร์","อาทิตย์"],daysShort:["อา","จ","อ","พ","พฤ","ศ","ส","อา"],daysMin:["อา","จ","อ","พ","พฤ","ศ","ส","อา"],months:["มกราคม","กุมภาพันธ์","มีนาคม","เมษายน","พฤษภาคม","มิถุนายน","กรกฎาคม","สิงหาคม","กันยายน","ตุลาคม","พฤศจิกายน","ธันวาคม"],monthsShort:["ม.ค.","ก.พ.","มี.ค.","เม.ย.","พ.ค.","มิ.ย.","ก.ค.","ส.ค.","ก.ย.","ต.ค.","พ.ย.","ธ.ค."],today:"วันนี้"}}(jQuery);} catch(e) {};

// Source: node_modules/select2/dist/js/i18n/th.js
try {/*! Select2 4.0.13 | https://github.com/select2/select2/blob/master/LICENSE.md */

!function(){if(jQuery&&jQuery.fn&&jQuery.fn.select2&&jQuery.fn.select2.amd)var n=jQuery.fn.select2.amd;n.define("select2/i18n/th",[],function(){return{errorLoading:function(){return"ไม่สามารถค้นข้อมูลได้"},inputTooLong:function(n){return"โปรดลบออก "+(n.input.length-n.maximum)+" ตัวอักษร"},inputTooShort:function(n){return"โปรดพิมพ์เพิ่มอีก "+(n.minimum-n.input.length)+" ตัวอักษร"},loadingMore:function(){return"กำลังค้นข้อมูลเพิ่ม…"},maximumSelected:function(n){return"คุณสามารถเลือกได้ไม่เกิน "+n.maximum+" รายการ"},noResults:function(){return"ไม่พบข้อมูล"},searching:function(){return"กำลังค้นข้อมูล…"},removeAllItems:function(){return"ลบรายการทั้งหมด"}}}),n.define,n.require}();} catch(e) {}

==> ChurchCRM-5.6.0.zip: churchcrm/locale/js/th_TH.js <==
// Source: locale/JSONKeys/th_TH.json
try {window.CRM.i18keys = {
    "Cannot execute query.": "ไม่สามารถสืบค้นฐานข้อมูล",
    "Delete": "ลบ",
    "Cancel": "ยกเลิก",
    "Save": "บันทึก",
    "Unassigned": "ยังไม่ได้กำหนด",
    "None": "ไม่มี",
    "City": "เมือง",
    "State": "จังหวัด",
    "Country": "ประเทศ",
    "Phone": "โทรศัพท์",
    "Email": "อีเมล",
    "Credit Card": "บัตรเครดิต",
    "Backup Database": "ฐานข้อมูลสำรอง",
    "Select archive type": "เลือกประเภทเก็บ",
    "Re-type Password": "พิมพ์รหัสผ่านอีกครั้ง",
    "Winner": "ผู้ชนะ",
    "Price": "ราคา",
    "Enter Winners": "ลงชื่อผู้ชนะ",
    "CSV Export": "ส่งไฟล์ CSV ออก",
    "Field Selection": "เลือกฟิลด์",
    "Last Name": "นามสกุล",
    "Required": "ฟิลด์ที่จำเป็น",
    "First Name": "ชื่อจริง",
    "Middle Name": "ชื่อกลาง",
    "Zip": "รหัสไปรษณีย์",
    "Envelope": "ซอง",
    "Work/Other Email": "อีเมล ที่ทำงาน/ที่อื่นๆ",
    "Membership Date": "วันที่เป็นสมาชิก",
    "Birth / Anniversary Date": "วันเกิด / วันครอบรอบแต่งงาน",
    "Age / Years Married": "อายุ / แต่งงานกี่ปีแล้ว",
    "Family Role": "บทบาทในครอบครัว",
    "Filters": "ฟิลเตอร์",
    "Based on filters below..": "ขึ้นอยู่กับฟิลเตอร์ด้านล่าง",
    "People in Cart (filters ignored)": "คนในรถเข็น",
    "Use Ctrl Key to select multiple": "ใช้ Ctrl คีย์เพื่อเลือกหลาย",
    "Don't Filter": "ไม่ใช้ฟิลเตอร์",
    "Male": "ชาย",
    "Female": "หญิง",
    "Group Membership": "สมาชิกกลุ่ม",
    "From:": "จาก",
    "To:": "เรียน",
    "Birthday Date": "วันเกิด",
    "Anniversary Date": "วันครบรอบแต่งงาน",
    "Output Method:": "วิธีการส่งออก",
    "Create File": "สร้างไฟล์",
    "Gender": "เพศ",
    "Donation Envelope": "ซองถวาย",
    "Home Phone": "โทรศัพท์บ้าน",
    "Work Phone": "โทรศัพท์ที่ทำงาน",
    "Mobile Phone": "โทรศัพท์มือถือ",
    "Work / Other Email": "อีเมล ที่ทำงาน / ที่อื่นๆ",
    "Birth Date": "วันเกิด",
    "Wedding Date": "วันแต่งงาน",
    "Make Family records based on last name and address": "ข้อมูลแต่ละครอบครัวโดยเรียงตามลำดับอักษรของนามสกุลและที่อยู่",
    "Patriarch": "ผู้ชายที่อยู่ในวงศาคณาญาติที่เราให้ความเคารพ",
    "Matriarch": "ผู้หญิงที่อยู่ในวงศาคณาญาติที่เราให้ความเคารพ",
    "Login": "เข้าสู่ระบบ",
    "Login Name": "ชื่อผู้ใช้",
    "Last Login": "เข้าสู่ระบบครั้งล่าสุด"
};} catch(e) {};

// Source: node_modules/@fullcalendar/core/locales/th.js
try {var l70 = {
    code: 'th',
    week: {
        dow: 1,
        doy: 4, // The week that contains Jan 4th is the first week of the year.
    },
    buttonText: {
        prev: 'ก่อนหน้า',
        next: 'ถัดไป',
        prevYear: 'ปีก่อนหน้า',
        nextYear: 'ปีถัดไป',
        year: 'ปี',
        today: 'วันนี้',
        month: 'เดือน',
        week: 'สัปดาห์',
        day: 'วัน',
        list: 'กำหนดการ',
    },
    weekText: 'สัปดาห์',
    allDayText: 'ตลอดวัน',
    moreLinkText: 'เพิ่มเติม',
    noEventsText: 'ไม่มีกิจกรรมที่จะแสดง',
};

export { l70 as default };
} catch(e) {};

// Source: node_modules/bootstrap-datepicker/dist/locales/bootstrap-datepicker.th.min.js
try {!function(a){a.fn.datepicker.dates.th={days:["อาทิตย์","จันทร์","อังคาร","พุธ","พฤหัส","ศุกร์","เสาร์","อาทิตย์"],daysShort:["อา","จ","อ","พ","พฤ","ศ","ส","อา"],daysMin:["อา","จ","อ","พ","พฤ","ศ","ส","อา"],months:["มกราคม","กุมภาพันธ์","มีนาคม","เมษายน","พฤษภาคม","มิถุนายน","กรกฎาคม","สิงหาคม","กันยายน","ตุลาคม","พฤศจิกายน","ธันวาคม"],monthsShort:["ม.ค.","ก.พ.","มี.ค.","เม.ย.","พ.ค.","มิ.ย.","ก.ค.","ส.ค.","ก.ย.","ต.ค.","พ.ย.","ธ.ค."],today:"วันนี้"}}(jQuery);} catch(e) {};

// Source: node_modules/select2/dist/js/i18n/th.js
try {/*! Select2 4.0.13 | https://github.com/select2/select2/blob/master/LICENSE.md */

!function(){if(jQuery&&jQuery.fn&&jQuery.fn.select2&&jQuery.fn.select2.amd)var n=jQuery.fn.select2.amd;n.define("select2/i18n/th",[],function(){return{errorLoading:function(){return"ไม่สามารถค้นข้อมูลได้"},inputTooLong:function(n){return"โปรดลบออก "+(n.input.length-n.maximum)+" ตัวอักษร"},inputTooShort:function(n){return"โปรดพิมพ์เพิ่มอีก "+(n.minimum-n.input.length)+" ตัวอักษร"},loadingMore:function(){return"กำลังค้นข้อมูลเพิ่ม…"},maximumSelected:function(n){return"คุณสามารถเลือกได้ไม่เกิน "+n.maximum+" รายการ"},noResults:function(){return"ไม่พบข้อมูล"},searching:function(){return"กำลังค้นข้อมูล…"},removeAllItems:function(){return"ลบรายการทั้งหมด"}}}),n.define,n.require}();} catch(e) {}
